==> ckmame-2.1.tar.xz: ckmame-2.1/src/ParserCm.h <==
#ifndef HAD_PARSER_CM_H
#define HAD_PARSER_CM_H

/*
  ParserCm.h -- parser for ClrMamePro dat files
  Copyright (C) 1999-2020 Dieter Baron and Thomas Klausner

  This file is part of ckmame, a program to check rom sets for MAME.
  The authors can be contacted at <ckmame@nih.at>

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in
     the documentation and/or other materials provided with the
     distribution.
  3. The name of the author may not be used to endorse or promote
     products derived from this software without specific prior
     written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY
  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
  GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
  IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
  IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "Parser.h"

#include <unordered_set>

class ParserCm : public Parser {
  public:
    bool parse() override;

    ParserCm(ParserSourcePtr source, const std::unordered_set<std::string>& exclude, const DatEntry* dat,
             OutputContext* output, Options options)
        : Parser(source, exclude, dat, output, std::move(options)), ignoring_line(false) {}
    ~ParserCm() override = default;

  private:
    enum State { TOP, GAME, PROG };

    class Tokenizer {
      public:
        explicit Tokenizer(const std::string& s) : string(s), position(0) {}

        std::string get();

      private:
        std::string string;
        size_t position;
    };

    std::unordered_set<std::string> warned_keywords;
    bool ignoring_line;
    void warn_unknown_keyword(const std::string& keyword);
};

#endif // HAD_PARSER_CM_H

==> ckmame-3.0.tar.xz: ckmame-3.0/src/ParserCm.h <==
#ifndef HAD_PARSER_CM_H
#define HAD_PARSER_CM_H

/*
  ParserCm.h -- parser for ClrMamePro dat files
  Copyright (C) 1999-2020 Dieter Baron and Thomas Klausner

  This file is part of ckmame, a program to check rom sets for MAME.
  The authors can be contacted at <ckmame@nih.at>

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in
     the documentation and/or other materials provided with the
     distribution.
  3. The name of the author may not be used to endorse or promote
     products derived from this software without specific prior
     written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY
  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
  GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
  IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
  IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "Parser.h"

#include <unordered_set>
#include <utility>

class ParserCm : public Parser {
  public:
    bool parse() override;

    ParserCm(ParserSourcePtr source, const std::unordered_set<std::string>& exclude, const DatEntry* dat,
             OutputContext* output, const Options& options)
        : Parser(std::move(source), exclude, dat, output, options), ignoring_line(false) {}
    ~ParserCm() override = default;

  private:
    enum State { TOP, GAME, PROG };

    class Tokenizer {
      public:
        explicit Tokenizer(std::string s) : string(std::move(s)), position(0) {}

        std::string get();

      private:
        std::string string;
        size_t position;
    };

    std::unordered_set<std::string> warned_keywords;
    bool ignoring_line;
    void warn_unknown_keyword(const std::string& keyword);
};

#endif // HAD_PARSER_CM_H
